==> libksysguard-5.18.4.1-1-aarch64.pkg.tar.xz: usr/lib/cmake/KF5SysGuard/KF5SysGuardConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was KF5SysGuardConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/KF5SysGuard" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

include(CMakeFindDependencyMacro)
find_dependency(Qt5Core 5.12.0)
find_dependency(Qt5Network 5.12.0)
find_dependency(Qt5Widgets 5.12.0)

find_dependency(KF5Config 5.66.0)
find_dependency(KF5I18n 5.66.0)
find_dependency(KF5IconThemes 5.66.0)

include("${CMAKE_CURRENT_LIST_DIR}/KF5SysGuardLibraryTargets.cmake")

==> libksysguard-5.27.10-1-aarch64.pkg.tar.xz: usr/lib/cmake/KF5SysGuard/KF5SysGuardConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was KF5SysGuardConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/KF5SysGuard" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

message(WARNING "The KF5:: namespace for KSysGuard targets is deprecated. Please use KSysGuard as namespace.")

include(CMakeFindDependencyMacro)
find_dependency(KSysGuard REQUIRED)

macro(add_sysguard_target _target)
    add_library(KF5::${_target} INTERFACE IMPORTED)
    set_target_properties(KF5::${_target} PROPERTIES
        INTERFACE_INCLUDE_DIRECTORIES $<TARGET_PROPERTY:KSysGuard::${_target},INTERFACE_INCLUDE_DIRECTORIES>
        INTERFACE_LINK_LIBRARIES KSysGuard::${_target}
    )
endmacro()

add_sysguard_target(SysGuard)
add_sysguard_target(ProcessCore)
add_sysguard_target(ProcessUi)
add_sysguard_target(LsofUi)
add_sysguard_target(SignalPlotter)
